export declare function arrayIsNotEmptyValid<T>(value: T[] | null | undefined): boolean;
export declare function positiveNumberNotNullValid(value: number | null | undefined): boolean;
export declare function numberPercentageNotNullValid(value: number | null | undefined): boolean;
export declare function numberNotNullValid(value: number | null | undefined): boolean;
export declare function stringNotNullValid(value: string | null | undefined): boolean;
export declare function stringNullableValid(value: string | null | undefined): boolean;
export declare function notNullValid<T>(value: T | null | undefined): value is T & {};
export declare function dateValid(value: Date | null | undefined): boolean;
export declare function dateRangeValid(value: (Date | null | undefined)[] | null | undefined): boolean;
export declare function emailValid(value: string | null | undefined): value is never;
export declare function numberOnlyValid(value: string | null | undefined): value is never;
export declare function urlValid(value: string | null | undefined): boolean;
export declare function colorValid(value: string | null | undefined): boolean;
export declare function passwordValid(value: string | null | undefined): value is never;
export declare function containsOnlyDigits(str: string): boolean;
/**
 * Validates a text string based on specified criteria.
 *
 * @param str - The text string to be validated.
 * @param length - The maximum length of the text string. Default is 50.
 * @param required - validField required.
 * @param pattern - The regular expression pattern to match against the text string. Default is /^[a-zA-Z0-9\/\-_.()\[\] ]+$/g.
 * @param invertRegex - The inverted regular expression pattern to match against the text string. Default is undefined.
 * @returns An object containing the validation result and a message describing any validation errors.
 */
export declare const textValidation: (str: string, length?: number, required?: boolean, pattern?: RegExp | false, invertRegex?: RegExp | false) => {
    valid: boolean;
    message: string;
};
