import * as react from 'react';
import { ReactNode, CSSProperties, RefObject } from 'react';
import * as react_jsx_runtime from 'react/jsx-runtime';
import { MenuOption as MenuOption$1 } from 'Components/interface';
import * as _mui_material from '@mui/material';
import { SxProps, Theme, TextFieldProps } from '@mui/material';
import { TreeItemProps } from '@mui/x-tree-view/TreeItem';
import { InputBaseProps } from '@mui/material/InputBase';
import { Modify as Modify$1 } from 'Commons/Types';
import { AlertColor } from '@mui/material/Alert';
import * as i18next from 'i18next';
import { i18n as i18n$1 } from 'i18next';
import { Location, Params } from 'react-router';
import moment from 'moment';

declare const INT_NUMBER_LIMIT: {
    minimum: number;
    maximum: number;
};

declare function formatNumberWithLanguage(num: number | bigint | undefined, language?: string): string;
type BinaryTreeNode = {
    value: string;
    left?: BinaryTreeNode;
    right?: BinaryTreeNode;
};
/** Calculate Value  */
declare function calculateValue(binary: BinaryTreeNode): number;
declare function isOperator(token: string): boolean;
declare function isOperand(token: string): boolean;
declare function tokenize(formula: string): string[];
declare function getPrecedence(operator: string): number;
declare function convertToPostfix(infix: string): string[];
declare function convertFormulaToBinaryTree(formula: string): BinaryTreeNode | undefined;
declare const replaceFieldsValue: (fields: {
    fieldName: string;
    value?: string | null;
}[], formula: string) => string;

declare function arrayIsNotEmptyValid<T>(value: T[] | null | undefined): boolean;
declare function positiveNumberNotNullValid(value: number | null | undefined): boolean;
declare function numberPercentageNotNullValid(value: number | null | undefined): boolean;
declare function numberNotNullValid(value: number | null | undefined): boolean;
declare function stringNotNullValid(value: string | null | undefined): boolean;
declare function stringNullableValid(value: string | null | undefined): boolean;
declare function notNullValid<T>(value: T | null | undefined): value is T & {};
declare function dateValid(value: Date | null | undefined): boolean;
declare function dateRangeValid(value: (Date | null | undefined)[] | null | undefined): boolean;
declare function emailValid(value: string | null | undefined): value is never;
declare function numberOnlyValid(value: string | null | undefined): value is never;
declare function urlValid(value: string | null | undefined): boolean;
declare function colorValid(value: string | null | undefined): boolean;
declare function passwordValid(value: string | null | undefined): value is never;
declare function containsOnlyDigits(str: string): boolean;
/**
 * Validates a text string based on specified criteria.
 *
 * @param str - The text string to be validated.
 * @param length - The maximum length of the text string. Default is 50.
 * @param required - validField required.
 * @param pattern - The regular expression pattern to match against the text string. Default is /^[a-zA-Z0-9\/\-_.()\[\] ]+$/g.
 * @param invertRegex - The inverted regular expression pattern to match against the text string. Default is undefined.
 * @returns An object containing the validation result and a message describing any validation errors.
 */
declare const textValidation: (str: string, length?: number, required?: boolean, pattern?: RegExp | false, invertRegex?: RegExp | false) => {
    valid: boolean;
    message: string;
};

type ValueBase = string | number;
interface MenuOption<T extends ValueBase> {
    value: T;
    text: string;
    key?: string;
    label?: ReactNode;
    disabled?: boolean;
    params?: any;
    level?: number;
    actions?: ReactNode;
    order?: number;
    directoryPath?: string;
    parentObjectId?: T;
    objectId?: T;
}
interface IOption {
    id: string;
    name: string;
}

type ICircularProgress = {
    styleWrap?: CSSProperties;
    styleIcon?: CSSProperties;
};
declare const CircularProgress: (props: ICircularProgress) => react_jsx_runtime.JSX.Element;

type Value = string | number;
type TreeItemOption = MenuOption$1<Value> & {
    description?: string;
    isFile?: boolean;
    isSystem?: boolean;
    objectTypeCode?: string;
};
type DirectoryTreeProps = {
    labelSearch: string;
    options: TreeItemOption[];
    defaultValue: string;
    rootDirectoryId: Value;
    titleSearch?: string;
    onChange(value: Value): void;
    onDirectoryOpen?: (id: Value) => void;
};

type FilterTreeViewProps = {
    items: TreeItemOption[];
    onDirectoryOpen: (id: TreeItemOption['value']) => void;
    onTreeItemClick: (id: TreeItemOption['value']) => void;
    rootDirectoryId: TreeItemOption['value'];
    isLoading?: boolean;
    sx?: SxProps<Theme>;
};

declare function FilterTreeView(props: FilterTreeViewProps): react_jsx_runtime.JSX.Element;

type ShowTreeItemProps = {
    rootItem: TreeItemOption;
    items: TreeItemOption[];
    onTreeItemClick: (id: Value) => void;
    loading?: boolean;
};

declare function ShowTreeItem(props: ShowTreeItemProps): react_jsx_runtime.JSX.Element;

type TreeItemWithActionProps = TreeItemProps & {
    itemId: string;
    labelIcon: ReactNode;
    labelText: string;
    actions?: ReactNode;
    onTreeItemClick?: () => void;
};

declare function TreeItemWithAction(props: TreeItemWithActionProps): react_jsx_runtime.JSX.Element;

declare function DirectoryTree(props: DirectoryTreeProps): react_jsx_runtime.JSX.Element;

declare function NoData(): react_jsx_runtime.JSX.Element;

type SearchType = 'searchString' | 'id';
type SearchBoxProps = Modify$1<InputBaseProps, {
    defaultValue?: string;
    includeSearchById?: boolean;
    onlyNumberString?: boolean;
    onSearch: (searchType: SearchType, searchString: string) => void;
    placeholderInput?: string;
    onClickAdvancedSearch?(): void;
    /** stylePaper => Style cho Paper của inputSearch */
    stylePaper?: object;
    /** variantPaper => Định dạng 'variant' cho Paper của inputSearch */
    variantPaper?: 'elevation' | 'outlined';
}>;

declare function SearchBox(props: SearchBoxProps): react_jsx_runtime.JSX.Element;

type CopyButtonProps = {
    id: string;
};
declare const CopyButton: (props: CopyButtonProps) => react_jsx_runtime.JSX.Element;

declare function TabLabel({ content, error, errContent, }: {
    content: ReactNode;
    error?: boolean;
    errContent?: ReactNode;
}): react_jsx_runtime.JSX.Element;

interface DrawerBaseProps {
    title?: ReactNode;
    disableButtonSubmit?: boolean;
    isLoadingButtonSubmit?: boolean;
    customAction?: React.ReactElement;
    onSubmit?: () => void;
    open: boolean;
    onClose?: () => void;
    otherNodes?: ReactNode;
    children: ReactNode;
    width?: string | number;
    childrenWrapperStyle?: SxProps<Theme>;
}
/**
 * Drawer không trả về state
 * @param{DrawerBaseProps} props
 * @returns
 */
declare const DrawerBase: (props: DrawerBaseProps) => react_jsx_runtime.JSX.Element;

interface ModalDrawerProps extends Omit<DrawerBaseProps, 'open'> {
    confirmExit?: boolean;
    confirmSave?: boolean;
    messageConfirmSave?: string;
    onSubmit?: () => Promise<any> | void;
    onClose?: () => void;
}
declare const enum CloseAction {
    Reload = "Reload",
    Close = "Close",
    ReloadDirectory = "ReloadDirectory"
}
declare const DrawerWrapper: (props: ModalDrawerProps) => react_jsx_runtime.JSX.Element;

interface EnhancedDialogProps {
    title?: string;
    label?: string;
    content?: ReactNode;
    isOpen: boolean;
    confirmExit?: boolean;
    notIncludeInput?: boolean;
    onSubmit?: (text: string) => void;
    onClose?: () => void;
    textFieldProps?: TextFieldProps;
}
declare const EnhancedDialog: (props: EnhancedDialogProps) => react_jsx_runtime.JSX.Element;

declare const usePath: () => string;

declare function useHover<T extends HTMLElement = HTMLElement>(elementRef: RefObject<T>): boolean;

declare const useElementResize: (ref?: RefObject<HTMLElement>) => {
    resize: {
        width: number;
        height: number;
    };
    hasScrollX: boolean;
    hasScrollY: boolean;
};

interface Props {
    onTriggered: (e: Event) => void;
    disableClick?: boolean;
    disableTouch?: boolean;
    disableKeys?: boolean;
    allowAnyKey?: boolean;
    triggerKeys?: string[];
}
/**
 * Hook used to detect clicks outside a component (or an escape key press). onTriggered function is triggered on `click`, `touch` or escape `keyup` event.
 *
 */
declare function useDetectClickOutside({ onTriggered, disableClick, disableTouch, disableKeys, allowAnyKey, triggerKeys, }: Props): react.RefObject<null>;

declare enum TIMELINE_TYPE {
    HOUR = 0,
    DAY = 1
}
declare enum SortEnumType {
    Asc = "ASC",
    Desc = "DESC"
}

type Modify<T, R> = Omit<T, keyof R> & R;
interface FileResponse {
    data: Blob;
    status: number;
    fileName?: string;
    headers?: {
        [name: string]: any;
    };
}
interface AnalyticDataProviderModel {
    timeline: number;
    view: number;
    click: number;
    ctr: number;
}
type Timestamp = {
    seconds: number;
    nanos: number;
};
type ObjectDefinition = {
    id: number;
    objectTypeCode?: string;
    fieldName?: string;
    fieldPath?: string;
    description?: string;
    isPrimaryKey?: boolean;
};

declare const AppContext: react.Context<{
    snackbar: (severity?: AlertColor, message?: string, autoHideDuration?: number) => void;
    alert: (message: string, title?: string) => void;
    confirm: (okFunction?: () => void, cancelFunction?: () => void, message?: string, title?: string) => void;
}>;

declare const useAppHelper: () => {
    snackbar: (severity?: _mui_material.AlertColor, message?: string, autoHideDuration?: number) => void;
    alert: (message: string, title?: string) => void;
    confirm: (okFunction?: () => void, cancelFunction?: () => void, message?: string, title?: string) => void;
};

/**
 * Append common Components
 * snackbar, alert, confirm
 */
declare const AppProvider: ({ children }: {
    children: ReactNode;
}) => react_jsx_runtime.JSX.Element;

declare const i18n: i18next.i18n;

declare const I18nProvider: ({ children, i18nData }: {
    children: ReactNode;
    i18nData: i18n$1;
}) => react_jsx_runtime.JSX.Element;

declare const checkFullControl: (permission?: number) => boolean;

/**
 * Chứa các hàm tiện ích hỗ trợ giao tiếp với API.
 * Tự động xử lý logic liên quan đến fetch, retry, timeout, hoặc các yêu cầu phức tạp.
 */

/**
 * Get the value of a cookie
 * Source: https://vanillajstoolkit.com/helpers/getcookie/
 * @param name - The name of the cookie
 * @return The cookie value
 */
declare function getCookie(name: string): string | undefined;
declare function getQueryVariable(variable: string): string;
declare function generateUUID(): string;
declare const getRoutePath: (location: Location, params: Params) => string;
declare const offlinePaginate: (array: any, pageIndex: number, pageSize: number) => any[];

/**
 * Xử lý dữ liệu dạng mảng hoặc object một cách đơn giản và hiệu quả.
 * Tăng cường khả năng thao tác với danh sách dữ liệu.
 */

declare function convertArrayToObject(array: any, keyName: string): any;
declare const convertDataSetPattern: (data: AnalyticDataProviderModel[]) => {
    data: number[];
    label: string;
    type: string;
    color: string;
}[];
declare const updateObjectFields: (originalObj: any, changedValues: any) => any;
declare function formatChartNumber(val: any, language: string): string;
declare const setObject: <O extends {}>(obj: O, arrKey: Array<keyof O>, value: unknown) => void;
declare function nameExportStandard(nameFeature?: string, objectName?: string, subTitle?: string): string;
declare const formatJSON: (val: string) => string;

/**
 * Quản lý và xử lý thời gian, ngày tháng một cách tiện lợi và nhất quán.
 * Giảm thiểu lỗi khi thao tác với định dạng ngày giờ.
 */

declare function dateToString(date: moment.MomentInput): string;
declare function calculatorDirectoryIdRoot(directoriesTree: any): number;
declare const convertTimeLine: (value: number) => string;
declare const convertDateTimeToTimestamp: (date: Date) => Timestamp;
declare const convertTimestampToDateTime: (timestamp: Timestamp) => Date;
declare const dateTimeToString: (dateTime: Date, format: string) => string;
declare const convertTimelineToDateTime: (timeline: string, timelineType: TIMELINE_TYPE) => Date;
declare function dateToStringDDMMYYYY(date: any): string | null;
declare function timestampToStringDDMMYYYY(date: any): string | null;
declare const getStartOfDay: (dateTime: Date) => Date;
declare const getToday: () => Date;
declare function fillMissingDates(data: Array<{
    x: string;
    y: number;
}>, startDate?: string | Date | number, endDate?: string | Date | number, format?: string | 'YYYYMMDD' | 'YYYYMMDDHH'): {
    x: string;
    y: number;
}[];
declare function parseJSON(str: string): any;

/**
 * Xử lý các thao tác số học và toán học một cách tiện lợi.
 * Hỗ trợ các phép toán phức tạp hoặc tối ưu hóa các logic tính toán thường dùng.
 */
declare function formatNumber(num: number | bigint | string | undefined): string;
declare function roundDecimalNumber(number: any): string | null;
declare function WMAPEcalculator(data: any): number | "∞";

/**
 * Hỗ trợ xử lý chuỗi văn bản, từ việc định dạng, chuyển đổi cho đến kiểm tra tính hợp lệ.
 * Đảm bảo sự nhất quán và tái sử dụng các logic liên quan đến chuỗi.
 */
declare function changeToAlias(str?: string): string;
declare const toCapitalize: (str: string, lower?: boolean) => string;

/**
 * Đảm bảo dữ liệu được kiểm tra tính hợp lệ trước khi xử lý hoặc gửi đi.
 * Được sử dụng nhiều trong xử lý form, API, hoặc đầu vào từ người dùng.
 */
/**
 *  check string list ap input
 *
 * @param {string} stringListAP
 * @returns {boolean}
 */
declare function checkValidStringListAP(stringListAP?: string): boolean;
declare function checkValidMacAddress(string?: string): boolean;
declare function checkValidUrl(url: string | undefined): boolean;
declare function validateNumber(value?: string | number): boolean;

export { type AnalyticDataProviderModel, AppContext, AppProvider, type BinaryTreeNode, CircularProgress, DrawerBase as ClassicBaseDrawer, DrawerWrapper as ClassicDrawer, CloseAction, CopyButton, type CopyButtonProps, EnhancedDialog as DeprecatedEnhancedDialog, DirectoryTree, type DirectoryTreeProps, type DrawerBaseProps, type EnhancedDialogProps, type FileResponse, FilterTreeView, I18nProvider, type ICircularProgress, INT_NUMBER_LIMIT, type IOption, type MenuOption, type ModalDrawerProps, type Modify, NoData, type ObjectDefinition, SearchBox, type SearchBoxProps, type SearchType, ShowTreeItem, SortEnumType, TIMELINE_TYPE, TabLabel, type Timestamp, type TreeItemOption, TreeItemWithAction, type Value, type ValueBase, WMAPEcalculator, arrayIsNotEmptyValid, calculateValue, calculatorDirectoryIdRoot, changeToAlias, checkFullControl, checkValidMacAddress, checkValidStringListAP, checkValidUrl, colorValid, containsOnlyDigits, convertArrayToObject, convertDataSetPattern, convertDateTimeToTimestamp, convertFormulaToBinaryTree, convertTimeLine, convertTimelineToDateTime, convertTimestampToDateTime, convertToPostfix, dateRangeValid, dateTimeToString, dateToString, dateToStringDDMMYYYY, dateValid, emailValid, fillMissingDates, formatChartNumber, formatJSON, formatNumber, formatNumberWithLanguage, generateUUID, getCookie, getPrecedence, getQueryVariable, getRoutePath, getStartOfDay, getToday, i18n as i18nLib, isOperand, isOperator, nameExportStandard, notNullValid, numberNotNullValid, numberOnlyValid, numberPercentageNotNullValid, offlinePaginate, parseJSON, passwordValid, positiveNumberNotNullValid, replaceFieldsValue, roundDecimalNumber, setObject, stringNotNullValid, stringNullableValid, textValidation, timestampToStringDDMMYYYY, toCapitalize, tokenize, updateObjectFields, urlValid, useAppHelper, useDetectClickOutside, useElementResize, useHover, usePath, validateNumber };
